# This file is used to enable type hinting for the `fury.animation` module.
# explicit definition of `__all__` will enable type inference for engines.

__all__ = [
    "Animation",
    "CameraAnimation",
    "Timeline",
    "euclidean_distances",
    "get_next_timestamp",
    "get_previous_timestamp",
    "get_time_tau",
    "get_timestamps_from_keyframes",
    "get_values_from_keyframes",
    "lerp",
    "color_interpolator",
    "cubic_bezier_interpolator",
    "cubic_spline_interpolator",
    "hsv_color_interpolator",
    "lab_color_interpolator",
    "linear_interpolator",
    "slerp",
    "spline_interpolator",
    "step_interpolator",
    "tan_cubic_spline_interpolator",
    "xyz_color_interpolator",
]

from .animation import Animation, CameraAnimation
from .helpers import (
    euclidean_distances,
    get_next_timestamp,
    get_previous_timestamp,
    get_time_tau,
    get_timestamps_from_keyframes,
    get_values_from_keyframes,
    lerp,
)
from .interpolator import (
    color_interpolator,
    cubic_bezier_interpolator,
    cubic_spline_interpolator,
    hsv_color_interpolator,
    lab_color_interpolator,
    linear_interpolator,
    slerp,
    spline_interpolator,
    step_interpolator,
    tan_cubic_spline_interpolator,
    xyz_color_interpolator,
)
from .timeline import Timeline
